==> ozone-1.2.0-src.tar.gz: ozone-1.2.0-src/hadoop-ozone/ozone-manager/src/main/java/org/apache/hadoop/ozone/om/OMStarterInterface.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership.  The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.hadoop.ozone.om;

import org.apache.hadoop.hdds.conf.OzoneConfiguration;
import org.apache.hadoop.security.authentication.client.AuthenticationException;
import java.io.IOException;

/**
 * This interface is used by the OzoneManagerStarter class to allow the
 * dependencies to be injected to the CLI class.
 */
public interface OMStarterInterface {
  void start(OzoneConfiguration conf) throws IOException,
      AuthenticationException;
  boolean init(OzoneConfiguration conf) throws IOException,
      AuthenticationException;
  void bootstrap(OzoneConfiguration conf) throws IOException,
      AuthenticationException;
  void startAndCancelPrepare(OzoneConfiguration conf) throws IOException,
      AuthenticationException;
}

==> ozone-1.3.0-src.tar.gz: ozone-1.3.0-src/hadoop-ozone/ozone-manager/src/main/java/org/apache/hadoop/ozone/om/OMStarterInterface.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership.  The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.hadoop.ozone.om;

import org.apache.hadoop.hdds.conf.OzoneConfiguration;
import org.apache.hadoop.security.authentication.client.AuthenticationException;
import java.io.IOException;

/**
 * This interface is used by the OzoneManagerStarter class to allow the
 * dependencies to be injected to the CLI class.
 */
public interface OMStarterInterface {
  void start(OzoneConfiguration conf) throws IOException,
      AuthenticationException;
  boolean init(OzoneConfiguration conf) throws IOException,
      AuthenticationException;
  void bootstrap(OzoneConfiguration conf, boolean force) throws IOException,
      AuthenticationException;
  void startAndCancelPrepare(OzoneConfiguration conf) throws IOException,
      AuthenticationException;
}
